@@ -5,8 +5,7 @@ import copy
 from configparser import ConfigParser
 import itertools
 from copy import deepcopy
-from twiggy import log
-log = log.name('emp ')
+import logging
 
 import numpy as np
 import pandas as pd
@@ -87,6 +86,14 @@ division_note = \
     and across eight subplots when the patch is split into 2 parts along x_col
     and 4 parts along y_col."""
 
+start_emp_example = \
+    """>>> # Using the ANBO data provided in demo_files_ANBO.zip found at
+    >>> # https://github.com/jkitzes/macroeco/releases/
+
+    >>> import macroeco as meco
+
+    >>> # Pass in path to metadata in order to make patch object
+    >>> pat = meco.empirical.Patch('~/Desktop/ANBO.txt')"""
 
 class Patch(object):
     """
@@ -134,6 +141,22 @@ class Patch(object):
 
     An empty Patch object can be created with a metadata_path of None.
 
+    Examples
+    --------
+
+    >>> # Using the ANBO data provided in demo_files_ANBO.zip found at
+    >>> # https://github.com/jkitzes/macroeco/releases/
+
+    >>> import macroeco as meco
+
+    >>> # Pass in path to metadata in order to make patch object
+    >>> pat = meco.empirical.Patch('~/Desktop/ANBO.txt')
+
+    >>> # Subset data upon loading using subset string.
+    >>> # Should be a conditional statements separated by a semicolon
+    >>> pat = meco.empirical.Patch('~/Desktop/ANBO.txt',
+                                    subset="year==2010; row>2")
+
     """
 
     def __init__(self, metadata_path, subset=''):
@@ -274,7 +297,12 @@ def _subset_table(full_table, subset):
 
     valid = np.ones(len(full_table), dtype=bool)
     for condition in conditions:
-        this_valid = eval('full_table.' + condition)
+        col = re.split("[<>=!]", condition)[0]
+        comp = condition.replace(col, "")
+        try:
+            this_valid = eval("full_table['{0}']{1}".format(col, comp))
+        except KeyError as e: # catch error and redisplay for twiggy
+            raise KeyError("Column '%s' not found" % e.message)
         valid = np.logical_and(valid, this_valid)
 
     return full_table[valid]
@@ -346,7 +374,7 @@ def _subset_meta(full_meta, subset, incremented=False):
 
 
 @log_start_end
-@doc_sub(metric_params, metric_return, cols_note, splits_note)
+@doc_sub(metric_params, metric_return, cols_note, splits_note, start_emp_example)
 def sad(patch, cols, splits, clean=True):
     """
     Calculates an empirical species abundance distribution
@@ -369,6 +397,81 @@ def sad(patch, cols, splits, clean=True):
 
     {3}
 
+    Examples
+    --------
+
+    {4}
+
+    >>> # Get the SAD of the full plot
+    >>> sad = meco.empirical.sad(pat, 'spp_col:spp; count_col:count', '')
+
+    >>> # Extract the SAD
+    >>> sad_df = sad[0][1]
+    >>> sad_df
+           spp     y
+    0    arsp1     2
+    1     cabr    31
+    2   caspi1    58
+    3     chst     1
+    4    comp1     5
+    5     cran     4
+    6     crcr    65
+    7    crsp2    79
+    8     enfa     1
+    9     gnwe    41
+    10   grass  1110
+    11   lesp1     1
+    12    magl     1
+    13    mesp     6
+    14    mobe     4
+    15    phdi   210
+    16   plsp1     1
+    17    pypo    73
+    18    sasp     2
+    19    ticr   729
+    20   unsh1     1
+    21   unsp1    18
+    22   unsp3     1
+    23   unsp4     1
+
+    >>> # Get SAD for 4 subplots within the full plot and keep absent species
+    >>> # using clean = False
+    >>> sad_subplots = meco.empirical.sad(pat, 'spp_col:spp; count_col:count', splits = "row:2; column:2", clean=False)
+    >>> len(sad_subplots)
+    4
+
+    >>> # Look at SAD in one of the 4 cells
+    >>> sad_subplots[0]
+    ('row>=-0.5; row<1.5; column>=-0.5; column<1.5',
+           spp    y
+    0    arsp1    0
+    1     cabr    7
+    2   caspi1    0
+    3     chst    1
+    4    comp1    1
+    5     cran    3
+    6     crcr   21
+    7    crsp2   16
+    8     enfa    0
+    9     gnwe    8
+    10   grass  236
+    11   lesp1    0
+    12    magl    0
+    13    mesp    4
+    14    mobe    0
+    15    phdi   33
+    16   plsp1    1
+    17    pypo    8
+    18    sasp    2
+    19    ticr  317
+    20   unsh1    1
+    21   unsp1    0
+    22   unsp3    1
+    23   unsp4    1)
+
+    See http://www.macroeco.org/tutorial_macroeco.html for additional
+    examples and explanation
+
     """
 
     (spp_col, count_col), patch = \
@@ -402,7 +505,7 @@ def sad(patch, cols, splits, clean=True):
 
 
 @log_start_end
-@doc_sub(metric_params, metric_return, cols_note, splits_note)
+@doc_sub(metric_params, metric_return, cols_note, splits_note, start_emp_example)
 def ssad(patch, cols, splits):
     """
     Calculates an empirical intra-specific spatial abundance distribution
@@ -422,6 +525,43 @@ def ssad(patch, cols, splits):
 
     {3}
 
+    Examples
+    --------
+
+    {4}
+
+    >>> # Get the spatial abundance distribution for all species for each of
+    >>> # the cells in the ANBO plot
+    >>> all_spp_ssads = meco.empirical.ssad(pat, cols='spp_col:spp; count_col:count', splits='row:4; column:4')
+
+    >>> # Convert to dict for easy searching
+    >>> all_ssads_dict = dict(all_spp_ssads)
+
+    >>> # Look up the spatial abundance distribution for 'grass'
+    >>> all_ssads_dict['grass']
+         y
+    0    42
+    1    20
+    2    60
+    3    60
+    4    88
+    5    86
+    6    20
+    7     0
+    8   110
+    9    12
+    10  115
+    11  180
+    12  160
+    13  120
+    14   26
+    15   11
+
+    >>> # Each value in 'y' gives the abundance of grass in one of the 16 cells
+
+    See http://www.macroeco.org/tutorial_macroeco.html for additional
+    examples and explanation
+
     """
 
     # Get and check SAD
@@ -446,7 +586,8 @@ def ssad(patch, cols, splits):
 
 
 @log_start_end
-@doc_sub(metric_params, metric_return, cols_note, splits_note, division_note)
+@doc_sub(metric_params, metric_return, cols_note, splits_note, division_note,
+            start_emp_example)
 def sar(patch, cols, splits, divs, ear=False):
     """
     Calculates an empirical species area or endemics area relationship
@@ -476,6 +617,39 @@ def sar(patch, cols, splits, divs, ear=False):
 
     {4}
 
+    Examples
+    --------
+
+    {5}
+
+    >>> # Get the SAR at the full area (1,1), 1 x 2 division,
+    >>> # 2 x 1 division, 2 x 2 division, 2 x 4 division, 4 x 2 division, and
+    >>> # 4 x 4 division
+    >>> sar = meco.empirical.sar(pat,
+                cols='spp_col:spp; count_col:count; x_col:row; y_col:column',
+                splits="",
+                divs="1,1; 1,2; 2,1; 2,2; 2,4; 4,2; 4,4")
+
+    >>> sar[0][1]
+       div  n_individs    n_spp   x        y
+    0  1,1   2445.0000  24.0000  16  24.0000
+    1  1,2   1222.5000  18.5000   8  18.5000
+    2  2,1   1222.5000  17.0000   8  17.0000
+    3  2,2    611.2500  13.5000   4  13.5000
+    4  2,4    305.6250  10.1250   2  10.1250
+    5  4,2    305.6250  10.5000   2  10.5000
+    6  4,4    152.8125   7.5625   1   7.5625
+
+    The column div gives the divisions specified in the function call. The
+    column n_individs specifies the average number of individuals across the
+    cells made from the given division. n_spp gives the average species across
+    the cells made from the given division. x gives the absolute area of a
+    cell for the given division. y gives the same information as n_spp and is
+    included for easy plotting.
+
+    See http://www.macroeco.org/tutorial_macroeco.html for additional
+    examples and explanation
+
     """
 
     def sar_y_func(spatial_table, all_spp):
@@ -543,8 +717,11 @@ def _split_divs(divs):
     if type(divs) == type((1,1)):  # Tuple (occurs when main evals single div)
         subdivlist = [str(divs)[1:-1]]
     else: # String
+
         subdivlist = divs.split(';')
-    return subdivlist
+
+    # Clean divlist
+    return ["".join(s.strip().split(" ")) for s in subdivlist]
 
 
 @log_start_end
@@ -645,7 +822,12 @@ def _yield_spatial_table(patch, div, spp_col, count_col, x_col, y_col):
 
     """
 
-    div_split_list = div.replace(';','').split(',')
+    # Catch error if you don't use ; after divs in comm_grid in MacroecoDesktop
+    try:
+        div_split_list = div.replace(';','').split(',')
+    except AttributeError:
+        div_split_list = str(div).strip("()").split(',')
+
     div_split = (x_col + ':' + div_split_list[0] + ';' +
                  y_col + ':' + div_split_list[1])
 
@@ -1025,7 +1207,7 @@ def _yield_subpatches(patch, splits, name='split'):
     if splits:
         subset_list = _parse_splits(patch, splits)
         for subset in subset_list:
-            log.info('Analyzing subset %s: %s' % (name, subset))
+            logging.info('Analyzing subset %s: %s' % (name, subset))
             subpatch = copy.copy(patch)
             subpatch.table = _subset_table(patch.table, subset)
             subpatch.meta, subpatch.incremented = _subset_meta(patch.meta,
@@ -1176,7 +1358,7 @@ def empirical_cdf(data):
     vals = pd.Series(data).value_counts()
     ecdf = pd.DataFrame(data).set_index(keys=0)
     probs = pd.DataFrame(vals.sort_index().cumsum() / np.float(len(data)))
-    ecdf = ecdf.join(probs, how="right")
+    ecdf = ecdf.join(probs)
     ecdf = ecdf.reset_index()
     ecdf.columns = ['data', 'ecdf']
 
